def temp-table tt field f1 as integer field f11 as integer
                  index idx1 f1.
def temp-table tt2 field f2 as integer field f22 as integer
                  index idx2 f2.
def temp-table tt3 field f3 as integer field f33 as integer
                  index idx3 f3.

// ======================= SINGLE-TABLE FOR =======================

// for record phrase with implicit sort
open query q1 for each tt.
// implicit sort => adaptive query

// for record phrase with explicit sort
open query q1 for each tt by f1. 
// explicit sort with index => adaptive query

// for record phrase with explicit sort by unindexed field
open query q1 for each tt by f11. 
// explicit sort without index => preselect query

// ======================= SINGLE-TABLE PRESELECT =======================

// preselect record phrase with implicit sort
open query q1 preselect each tt. 
// preselect phrase => preselect query

// preselect record phrase with explicit sort
open query q1 preselect each tt by f1. 
// preselect phrase => preselect query

// preselect record phrase with explicit sort by unindexed field
open query q1 preselect each tt by f11.
// preselect phrase => preselect query

// ======================= MULTI-TABLE EACH FOR ======================= 

// multi-table for record phrase with each and implicit sort
open query q1 for each tt, each tt2. 
// implicit sort => compound query => adaptive query !!!

// multi-table for record phrase with each and explicit sort by field in first table
open query q1 for each tt, each tt2 by f1. 
// explicit sort by index on the first table => compound query => adaptive query !!!

// multi-table for record phrase with each and explicit sort by field in first table
open query q1 for each tt, each tt2 by f11. 
// explicit sort without index on the first table => compound query => adaptive query ???

// multi-table for record phrase with each and explicit sort by field in second table
open query q1 for each tt, each tt2 by f2.
// explicit sort (by index - not relevant) on the second table => preselect query

// multi-table for record phrase with each and explicit sort by unindexed field in second table
open query q1 for each tt, each tt2 by f22. 
// explicit sort (by non-index - not relevant) on the second table => preselect query

// ======================= MULTI-TABLE EACH PRESELECT ======================= 

// multi-table preselect record phrase with each and implicit sort
open query q1 preselect each tt, each tt2. 
// preselect phrase => preselect query

// multi-table preselect record phrase with each and explicit sort by field in first table
open query q1 preselect each tt, each tt2 by f1. 
// preselect phrase => preselect query

// multi-table preselect record phrase with each and explicit sort by field in first table
open query q1 preselect each tt, each tt2 by f11. 
// preselect phrase => preselect query

// multi-table preselect record phrase with each and explicit sort by field in second table
open query q1 preselect each tt, each tt2 by f2. 
// preselect phrase => preselect query

// multi-table preselect record phrase with each and explicit sort by unindexed field in second table
open query q1 preselect each tt, each tt2 by f22. 
// preselect phrase => preselect query

// ======================= MULTI-TABLE EACH + FIRST/LAST FOR ======================= 

// multi-table for record phrase with first and implicit sort
open query q1 for each tt, first tt2.
// implicit sort and first => compound query => adaptive query !!!

// multi-table for record phrase with last and explicit sort by field in first table
open query q1 for each tt, last tt2 by f1.
// explicit sort by index on the first table and last => compound query => adaptive query !!!

// multi-table for record phrase with first and explicit sort by field in first table
open query q1 for each tt, first tt2 by f11.
// explicit sort without index on the first table and first => compound query => adaptive query ???

// multi-table for record phrase with last and explicit sort by field in second table
open query q1 for each tt, last tt2 by f2.
// explicit sort (by index - not relevant) on the second table and last => preselect query

// multi-table for record phrase with first and explicit sort by unindexed field in second table
open query q1 for each tt, first tt2 by f22.
// explicit sort (by non-index - not relevant) on the second table and first => preselect query

// ======================= MULTI-TABLE FIRST/LAST + EACH FOR ======================= 

// multi-table for record phrase with first and implicit sort
open query q1 for first tt, each tt2.
// implicit sort and first => compound query => adaptive query !!!

// multi-table for record phrase with last and explicit sort by field in first table
open query q1 for last tt, each tt2 by f1.
// explicit sort by index on the first table and last => compound query => adaptive query !!!

// multi-table for record phrase with first and explicit sort by field in first table
open query q1 for first tt, each tt2 by f11.
// explicit sort without index on the first table and first => compound query => adaptive query ???

// multi-table for record phrase with last and explicit sort by field in second table
open query q1 for last tt, each tt2 by f2.
// explicit sort (by index - not relevant) on the second table and last => preselect query

// multi-table for record phrase with first and explicit sort by unindexed field in second table
open query q1 for first tt, each tt2 by f22.
// explicit sort (by non-index - not relevant) on the second table and first => preselect query

// ======================= MULTI-TABLE FIRST/LAST PRESELECT ======================= 

// multi-table preselect record phrase with last and implicit sort
open query q1 preselect each tt, last tt2.
// preselect phrase => preselect query

// multi-table preselect record phrase with first and explicit sort by field in first table
open query q1 preselect each tt, first tt2 by f1.
// preselect phrase => preselect query

// multi-table preselect record phrase with last and explicit sort by field in first table
open query q1 preselect each tt, last tt2 by f11.
// preselect phrase => preselect query

// multi-table preselect record phrase with first and explicit sort by field in second table
open query q1 preselect each tt, first tt2 by f2.
// preselect phrase => preselect query

// multi-table preselect record phrase with last and explicit sort by unindexed field in second table
open query q1 preselect each tt, last tt2 by f22.
// preselect phrase => preselect query